@@ -14,6 +14,7 @@ from .. import parsers, utils
 if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     import codegrade
 
+    from ..models.non_present_preference import NonPresentPreference
     from ..models.notification_setting import NotificationSetting
     from ..models.patch_notification_setting_user_setting_data import (
         PatchNotificationSettingUserSettingData,
@@ -21,9 +22,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from ..models.patch_ui_preference_user_setting_data import (
         PatchUiPreferenceUserSettingData,
     )
-    from ..models.result_data_get_user_setting_get_all_ui_preferences import (
-        ResultDataGetUserSettingGetAllUiPreferences,
-    )
+    from ..models.present_preference import PresentPreference
 
 
 _ClientT = t.TypeVar("_ClientT", bound="codegrade.client._BaseClient")
@@ -148,65 +147,15 @@ class UserSettingService(t.Generic[_ClientT]):
     def get_ui_preference(
         self,
         *,
-        name: "str",
+        name: Maybe["str"] = Nothing,
         token: Maybe["str"] = Nothing,
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
-    ) -> "t.Optional[bool]":
-        """Get a single UI preferences.
-
-        :param name: The preference name you want to get.
-        :param token: The token with which you want to get the preferences, if
-            not given the preferences are retrieved for the currently logged in
-            user.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The preferences for the user as described by the `token`.
-        """
-
-        url = "/api/v1/settings/ui_preferences/{name}".format(name=name)
-        params: t.Dict[str, t.Any] = {
-            **(extra_parameters or {}),
-        }
-        maybe_from_nullable(t.cast(t.Any, token)).if_just(
-            lambda val: params.__setitem__("token", val)
-        )
-
-        with self.__client as client:
-            resp = client.http.get(url=url, params=params)
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 200):
-            # fmt: off
-            # fmt: on
-            return parsers.JsonResponseParser(
-                rqa.Nullable(rqa.SimpleValue.bool)
-            ).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
-    def get_all_ui_preferences(
-        self,
-        *,
-        token: Maybe["str"] = Nothing,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "ResultDataGetUserSettingGetAllUiPreferences":
+    ) -> "t.Union[PresentPreference, NonPresentPreference, t.Mapping[str, t.Any]]":
         """Get ui preferences.
 
+        :param name: The preference name you want to get.
         :param token: The token with which you want to get the preferences, if
             not given the preferences are retrieved for the currently logged in
             user.
@@ -220,6 +169,9 @@ class UserSettingService(t.Generic[_ClientT]):
         params: t.Dict[str, t.Any] = {
             **(extra_parameters or {}),
         }
+        maybe_from_nullable(t.cast(t.Any, name)).if_just(
+            lambda val: params.__setitem__("name", val)
+        )
         maybe_from_nullable(t.cast(t.Any, token)).if_just(
             lambda val: params.__setitem__("token", val)
         )
@@ -230,14 +182,15 @@ class UserSettingService(t.Generic[_ClientT]):
 
         if utils.response_code_matches(resp.status_code, 200):
             # fmt: off
-            from ..models.result_data_get_user_setting_get_all_ui_preferences import (
-                ResultDataGetUserSettingGetAllUiPreferences,
-            )
+            from ..models.non_present_preference import NonPresentPreference
+            from ..models.present_preference import PresentPreference
 
             # fmt: on
             return parsers.JsonResponseParser(
-                parsers.ParserFor.make(
-                    ResultDataGetUserSettingGetAllUiPreferences
+                parsers.make_union(
+                    parsers.ParserFor.make(PresentPreference),
+                    parsers.ParserFor.make(NonPresentPreference),
+                    rqa.LookupMapping(rqa.AnyValue),
                 )
             ).try_parse(resp)
 
