@@ -22,6 +22,9 @@ from .any_redacted_auto_test_step_as_json import AnyRedactedAutoTestStepAsJSON
 from .api_codes import APICodes
 from .assignment import Assignment
 from .assignment_anonymization_algo import AssignmentAnonymizationAlgo
+from .assignment_default_grading_scale_points_setting import (
+    AssignmentDefaultGradingScalePointsSetting,
+)
 from .assignment_default_grading_scale_setting import (
     AssignmentDefaultGradingScaleSetting,
 )
@@ -32,9 +35,8 @@ from .assignment_done_type import AssignmentDoneType
 from .assignment_export_column import AssignmentExportColumn
 from .assignment_feedback import AssignmentFeedback
 from .assignment_grader import AssignmentGrader
-from .assignment_grading_scale import AssignmentGradingScale
-from .assignment_grading_settings_as_json import (
-    AssignmentGradingSettingsAsJSON,
+from .assignment_grading_scale_points_enabled_setting import (
+    AssignmentGradingScalePointsEnabledSetting,
 )
 from .assignment_kind import AssignmentKind
 from .assignment_login_link import AssignmentLoginLink
@@ -48,7 +50,11 @@ from .assignment_peer_feedback_settings import AssignmentPeerFeedbackSettings
 from .assignment_percentage_decimals_setting import (
     AssignmentPercentageDecimalsSetting,
 )
+from .assignment_percentage_grading_settings import (
+    AssignmentPercentageGradingSettings,
+)
 from .assignment_point_decimals_setting import AssignmentPointDecimalsSetting
+from .assignment_points_grading_settings import AssignmentPointsGradingSettings
 from .assignment_state_enum import AssignmentStateEnum
 from .assignment_template import AssignmentTemplate
 from .at_image_caching_enabled_setting import AtImageCachingEnabledSetting
@@ -277,6 +283,7 @@ from .find_element_interval_setting import FindElementIntervalSetting
 from .find_element_max_tries_setting import FindElementMaxTriesSetting
 from .first_phase_lti_launch_exception import FirstPhaseLTILaunchException
 from .fixture_like import FixtureLike
+from .fraction import Fraction
 from .frontend_site_settings import FrontendSiteSettings
 from .general_feedback_comment_base import GeneralFeedbackCommentBase
 from .general_feedback_comment_base_with_extended_replies import (
