@@ -466,6 +466,9 @@ class AllSiteSettings(FrontendSiteSettings):
             "ASSIGNMENT_DEFAULT_GRADING_SCALE": to_dict(
                 self.assignment_default_grading_scale
             ),
+            "ASSIGNMENT_DEFAULT_GRADING_SCALE_POINTS": to_dict(
+                self.assignment_default_grading_scale_points
+            ),
             "BLACKBOARD_ZIP_UPLOAD_ENABLED": to_dict(
                 self.blackboard_zip_upload_enabled
             ),
@@ -560,6 +563,9 @@ class AllSiteSettings(FrontendSiteSettings):
             "NEW_AUTO_TEST_COPYING_ENABLED": to_dict(
                 self.new_auto_test_copying_enabled
             ),
+            "ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED": to_dict(
+                self.assignment_grading_scale_points_enabled
+            ),
             "NEW_AUTO_TEST_OLD_SUBMISSION_AGE": to_dict(
                 self.new_auto_test_old_submission_age
             ),
@@ -624,6 +630,7 @@ class AllSiteSettings(FrontendSiteSettings):
             auto_test_max_global_setup_time=parsed.AUTO_TEST_MAX_GLOBAL_SETUP_TIME,
             auto_test_max_per_student_setup_time=parsed.AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME,
             assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
+            assignment_default_grading_scale_points=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE_POINTS,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
             rubric_enabled_for_teacher_on_submissions_page=parsed.RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE,
@@ -670,6 +677,7 @@ class AllSiteSettings(FrontendSiteSettings):
             csv_large_file_limit=parsed.CSV_LARGE_FILE_LIMIT,
             csv_too_many_errors_limit=parsed.CSV_TOO_MANY_ERRORS_LIMIT,
             new_auto_test_copying_enabled=parsed.NEW_AUTO_TEST_COPYING_ENABLED,
+            assignment_grading_scale_points_enabled=parsed.ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED,
             new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
             canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
         )
@@ -681,5 +689,6 @@ import os
 
 if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
     # fmt: off
-    pass
+    from .fraction import Fraction
+
     # fmt: on
