@@ -12,11 +12,12 @@ import cg_request_args as rqa
 from .. import parsers
 from ..utils import to_dict
 from .assignment_anonymization_algo import AssignmentAnonymizationAlgo
-from .assignment_grading_settings_as_json import (
-    AssignmentGradingSettingsAsJSON,
-)
 from .assignment_kind import AssignmentKind
 from .assignment_peer_feedback_settings import AssignmentPeerFeedbackSettings
+from .assignment_percentage_grading_settings import (
+    AssignmentPercentageGradingSettings,
+)
+from .assignment_points_grading_settings import AssignmentPointsGradingSettings
 from .cg_ignore_version import CGIgnoreVersion
 from .group_set import GroupSet
 from .submission_validator_input_data import SubmissionValidatorInputData
@@ -74,7 +75,7 @@ class Assignment:
     #: Settings that influence how the grade for a submission can be
     #: determined. TODO: Should we also move max\_grade and/or
     #: fixed\_max\_rubric\_points to the grading object?
-    grading: "AssignmentGradingSettingsAsJSON"
+    grading: "t.Union[AssignmentPointsGradingSettings, AssignmentPercentageGradingSettings]"
     #: The group set of this assignment. This is `None` if this assignment is
     #: not a group assignment.
     group_set: "t.Optional[GroupSet]"
@@ -250,7 +251,12 @@ class Assignment:
             ),
             rqa.RequiredArgument(
                 "grading",
-                parsers.ParserFor.make(AssignmentGradingSettingsAsJSON),
+                parsers.make_union(
+                    parsers.ParserFor.make(AssignmentPointsGradingSettings),
+                    parsers.ParserFor.make(
+                        AssignmentPercentageGradingSettings
+                    ),
+                ),
                 doc=(
                     "Settings that influence how the grade for a submission"
                     " can be determined. TODO: Should we also move max\\_grade"
