@@ -9,7 +9,9 @@ from dataclasses import dataclass, field
 
 import cg_request_args as rqa
 
+from .. import parsers
 from ..utils import to_dict
+from .fraction import Fraction
 
 
 @dataclass
@@ -75,6 +77,8 @@ class FrontendSiteSettings:
     auto_test_max_per_student_setup_time: "datetime.timedelta"
     #: The default value for the grading scale of new assignments.
     assignment_default_grading_scale: "t.Literal['percentage', 'points']"
+    #: The default points grading scale points of new assignments.
+    assignment_default_grading_scale_points: "Fraction"
     #: If enabled teachers are allowed to bulk upload submissions (and create
     #: users) using a zip file in a format created by Blackboard.
     blackboard_zip_upload_enabled: "bool"
@@ -214,6 +218,10 @@ class FrontendSiteSettings:
     #: Whether AutoTest 2.0 configuration importing from other assignments is
     #: enabled.
     new_auto_test_copying_enabled: "bool"
+    #: Whether it should be possible to set the maximum scale points for an
+    #: assignment using point-based scale. This is different from the
+    #: assignment max grade and can not be used with percentage-based scales.
+    assignment_grading_scale_points_enabled: "bool"
     #: The maximum age a submission can be before we do not retry subscribing
     #: to its result if it cannot be found the first time.
     new_auto_test_old_submission_age: "datetime.timedelta"
@@ -383,6 +391,14 @@ class FrontendSiteSettings:
                     " assignments."
                 ),
             ),
+            rqa.RequiredArgument(
+                "ASSIGNMENT_DEFAULT_GRADING_SCALE_POINTS",
+                parsers.ParserFor.make(Fraction),
+                doc=(
+                    "The default points grading scale points of new"
+                    " assignments."
+                ),
+            ),
             rqa.RequiredArgument(
                 "BLACKBOARD_ZIP_UPLOAD_ENABLED",
                 rqa.SimpleValue.bool,
@@ -745,6 +761,16 @@ class FrontendSiteSettings:
                     " assignments is enabled."
                 ),
             ),
+            rqa.RequiredArgument(
+                "ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether it should be possible to set the maximum scale"
+                    " points for an assignment using point-based scale. This"
+                    " is different from the assignment max grade and can not"
+                    " be used with percentage-based scales."
+                ),
+            ),
             rqa.RequiredArgument(
                 "NEW_AUTO_TEST_OLD_SUBMISSION_AGE",
                 rqa.RichValue.TimeDelta,
@@ -814,6 +840,9 @@ class FrontendSiteSettings:
             "ASSIGNMENT_DEFAULT_GRADING_SCALE": to_dict(
                 self.assignment_default_grading_scale
             ),
+            "ASSIGNMENT_DEFAULT_GRADING_SCALE_POINTS": to_dict(
+                self.assignment_default_grading_scale_points
+            ),
             "BLACKBOARD_ZIP_UPLOAD_ENABLED": to_dict(
                 self.blackboard_zip_upload_enabled
             ),
@@ -908,6 +937,9 @@ class FrontendSiteSettings:
             "NEW_AUTO_TEST_COPYING_ENABLED": to_dict(
                 self.new_auto_test_copying_enabled
             ),
+            "ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED": to_dict(
+                self.assignment_grading_scale_points_enabled
+            ),
             "NEW_AUTO_TEST_OLD_SUBMISSION_AGE": to_dict(
                 self.new_auto_test_old_submission_age
             ),
@@ -945,6 +977,7 @@ class FrontendSiteSettings:
             auto_test_max_global_setup_time=parsed.AUTO_TEST_MAX_GLOBAL_SETUP_TIME,
             auto_test_max_per_student_setup_time=parsed.AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME,
             assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
+            assignment_default_grading_scale_points=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE_POINTS,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
             rubric_enabled_for_teacher_on_submissions_page=parsed.RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE,
@@ -991,6 +1024,7 @@ class FrontendSiteSettings:
             csv_large_file_limit=parsed.CSV_LARGE_FILE_LIMIT,
             csv_too_many_errors_limit=parsed.CSV_TOO_MANY_ERRORS_LIMIT,
             new_auto_test_copying_enabled=parsed.NEW_AUTO_TEST_COPYING_ENABLED,
+            assignment_grading_scale_points_enabled=parsed.ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED,
             new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
             canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
         )
