@@ -11,7 +11,9 @@ import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
 
+from .. import parsers
 from ..utils import to_dict
+from .fraction import Fraction
 
 
 @dataclass
@@ -157,6 +159,8 @@ class PartialAllSiteSettings:
     assignment_default_grading_scale: Maybe[
         "t.Literal['percentage', 'points']"
     ] = Nothing
+    #: The default points grading scale points of new assignments.
+    assignment_default_grading_scale_points: Maybe["Fraction"] = Nothing
     #: If enabled teachers are allowed to bulk upload submissions (and create
     #: users) using a zip file in a format created by Blackboard.
     blackboard_zip_upload_enabled: Maybe["bool"] = Nothing
@@ -307,6 +311,10 @@ class PartialAllSiteSettings:
     #: Whether AutoTest 2.0 configuration importing from other assignments is
     #: enabled.
     new_auto_test_copying_enabled: Maybe["bool"] = Nothing
+    #: Whether it should be possible to set the maximum scale points for an
+    #: assignment using point-based scale. This is different from the
+    #: assignment max grade and can not be used with percentage-based scales.
+    assignment_grading_scale_points_enabled: Maybe["bool"] = Nothing
     #: The maximum age a submission can be before we do not retry subscribing
     #: to its result if it cannot be found the first time.
     new_auto_test_old_submission_age: Maybe["datetime.timedelta"] = Nothing
@@ -681,6 +689,14 @@ class PartialAllSiteSettings:
                     " assignments."
                 ),
             ),
+            rqa.OptionalArgument(
+                "ASSIGNMENT_DEFAULT_GRADING_SCALE_POINTS",
+                parsers.ParserFor.make(Fraction),
+                doc=(
+                    "The default points grading scale points of new"
+                    " assignments."
+                ),
+            ),
             rqa.OptionalArgument(
                 "BLACKBOARD_ZIP_UPLOAD_ENABLED",
                 rqa.SimpleValue.bool,
@@ -1075,6 +1091,16 @@ class PartialAllSiteSettings:
                     " assignments is enabled."
                 ),
             ),
+            rqa.OptionalArgument(
+                "ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether it should be possible to set the maximum scale"
+                    " points for an assignment using point-based scale. This"
+                    " is different from the assignment max grade and can not"
+                    " be used with percentage-based scales."
+                ),
+            ),
             rqa.OptionalArgument(
                 "NEW_AUTO_TEST_OLD_SUBMISSION_AGE",
                 rqa.RichValue.TimeDelta,
@@ -1217,6 +1243,9 @@ class PartialAllSiteSettings:
         self.assignment_default_grading_scale = maybe_from_nullable(
             self.assignment_default_grading_scale
         )
+        self.assignment_default_grading_scale_points = maybe_from_nullable(
+            self.assignment_default_grading_scale_points
+        )
         self.blackboard_zip_upload_enabled = maybe_from_nullable(
             self.blackboard_zip_upload_enabled
         )
@@ -1355,6 +1384,9 @@ class PartialAllSiteSettings:
         self.new_auto_test_copying_enabled = maybe_from_nullable(
             self.new_auto_test_copying_enabled
         )
+        self.assignment_grading_scale_points_enabled = maybe_from_nullable(
+            self.assignment_grading_scale_points_enabled
+        )
         self.new_auto_test_old_submission_age = maybe_from_nullable(
             self.new_auto_test_old_submission_age
         )
@@ -1528,6 +1560,10 @@ class PartialAllSiteSettings:
             res["ASSIGNMENT_DEFAULT_GRADING_SCALE"] = to_dict(
                 self.assignment_default_grading_scale.value
             )
+        if self.assignment_default_grading_scale_points.is_just:
+            res["ASSIGNMENT_DEFAULT_GRADING_SCALE_POINTS"] = to_dict(
+                self.assignment_default_grading_scale_points.value
+            )
         if self.blackboard_zip_upload_enabled.is_just:
             res["BLACKBOARD_ZIP_UPLOAD_ENABLED"] = to_dict(
                 self.blackboard_zip_upload_enabled.value
@@ -1714,6 +1750,10 @@ class PartialAllSiteSettings:
             res["NEW_AUTO_TEST_COPYING_ENABLED"] = to_dict(
                 self.new_auto_test_copying_enabled.value
             )
+        if self.assignment_grading_scale_points_enabled.is_just:
+            res["ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED"] = to_dict(
+                self.assignment_grading_scale_points_enabled.value
+            )
         if self.new_auto_test_old_submission_age.is_just:
             res["NEW_AUTO_TEST_OLD_SUBMISSION_AGE"] = to_dict(
                 self.new_auto_test_old_submission_age.value
@@ -1775,6 +1815,7 @@ class PartialAllSiteSettings:
             auto_test_max_global_setup_time=parsed.AUTO_TEST_MAX_GLOBAL_SETUP_TIME,
             auto_test_max_per_student_setup_time=parsed.AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME,
             assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
+            assignment_default_grading_scale_points=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE_POINTS,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
             rubric_enabled_for_teacher_on_submissions_page=parsed.RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE,
@@ -1825,6 +1866,7 @@ class PartialAllSiteSettings:
             csv_large_file_limit=parsed.CSV_LARGE_FILE_LIMIT,
             csv_too_many_errors_limit=parsed.CSV_TOO_MANY_ERRORS_LIMIT,
             new_auto_test_copying_enabled=parsed.NEW_AUTO_TEST_COPYING_ENABLED,
+            assignment_grading_scale_points_enabled=parsed.ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED,
             new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
             canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
         )
