@@ -10,12 +10,18 @@ import cg_request_args as rqa
 
 from ..parsers import ParserFor, make_union
 from ..utils import to_dict
+from .assignment_default_grading_scale_points_setting import (
+    AssignmentDefaultGradingScalePointsSetting,
+)
 from .assignment_default_grading_scale_setting import (
     AssignmentDefaultGradingScaleSetting,
 )
 from .assignment_description_enabled_setting import (
     AssignmentDescriptionEnabledSetting,
 )
+from .assignment_grading_scale_points_enabled_setting import (
+    AssignmentGradingScalePointsEnabledSetting,
+)
 from .assignment_max_points_enabled_setting import (
     AssignmentMaxPointsEnabledSetting,
 )
@@ -240,6 +246,7 @@ SiteSettingInput = t.Union[
     AutoTestMaxGlobalSetupTimeSetting,
     AutoTestMaxPerStudentSetupTimeSetting,
     AssignmentDefaultGradingScaleSetting,
+    AssignmentDefaultGradingScalePointsSetting,
     BlackboardZipUploadEnabledSetting,
     RubricsEnabledSetting,
     RubricEnabledForTeacherOnSubmissionsPageSetting,
@@ -290,6 +297,7 @@ SiteSettingInput = t.Union[
     CsvLargeFileLimitSetting,
     CsvTooManyErrorsLimitSetting,
     NewAutoTestCopyingEnabledSetting,
+    AssignmentGradingScalePointsEnabledSetting,
     NewAutoTestOldSubmissionAgeSetting,
     CanvasCourseIdCopyingEnabledSetting,
 ]
@@ -339,6 +347,7 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(AutoTestMaxGlobalSetupTimeSetting),
         ParserFor.make(AutoTestMaxPerStudentSetupTimeSetting),
         ParserFor.make(AssignmentDefaultGradingScaleSetting),
+        ParserFor.make(AssignmentDefaultGradingScalePointsSetting),
         ParserFor.make(BlackboardZipUploadEnabledSetting),
         ParserFor.make(RubricsEnabledSetting),
         ParserFor.make(RubricEnabledForTeacherOnSubmissionsPageSetting),
@@ -389,6 +398,7 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(CsvLargeFileLimitSetting),
         ParserFor.make(CsvTooManyErrorsLimitSetting),
         ParserFor.make(NewAutoTestCopyingEnabledSetting),
+        ParserFor.make(AssignmentGradingScalePointsEnabledSetting),
         ParserFor.make(NewAutoTestOldSubmissionAgeSetting),
         ParserFor.make(CanvasCourseIdCopyingEnabledSetting),
     ),
